<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Forum</name>
    <message>
        <location filename="../ForumInit.js" line="+2"/>
        <source>&amp;Forum</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Forum</translation>
    </message>
</context>
</TS>
